# This program is free software. See file LICENSE for details.

from math import floor

_typical_prefix_map = {
    0   :   "th",
    1   :   "st",
    2   :   "nd",
    3   :   "rd",
    4   :   "th",
    5   :   "th",
    6   :   "th",
    7   :   "th",
    8   :   "th",
    9   :   "th",
}

def ordinal(number: int) -> str:
    if not isinstance(number, int):
        raise TypeError(f"Expected {int} but got {type(number)}")
    
    elif _is_teenthish(abs(number)):
        return f"{number}th"
    else:
        return f"{number}{_typical_prefix_map[abs(number) % 10]}"

def _is_teenthish(number: int) -> bool:
    return (floor(number / 10) % 10) == 1



# Pape (a Python package)
# Copyright 2020 Carter Pape
# 
# This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or any later version.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.



# This program is free software. See file LICENSE for details.

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pape",
    version="0.0.2",
    author="Carter Pape",
    author_email="pape-python-package@carterpape.com",
    description="A package for personalized Python add-ons",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CarterPape/pape-python-package",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Natural Language :: English",
    ],
    python_requires='>=3',
)
